# MV0401-H2H4K60-001 API Control

This document will contain API commands for MV0401-H2H4K60-001 Multiviewer.
v1.0.0

- [MV0401-H2H4K60-001 API Control](#mv0401-h2h4k60-001-api-control)
  - [RS232 Default Settings](#rs232-default-settings)
  - [Telnet Settings](#telnet-settings)
  - [Commands](#commands)
    - [Get Firmware Version](#get-firmware-version)
    - [Set video mute status](#set-video-mute-status)
    - [Get Video Mute Status](#get-video-mute-status)
    - [Set Video output resolution](#set-video-output-resolution)
    - [Get Video output resolution](#get-video-output-resolution)
    - [Set Video output display layout](#set-video-output-display-layout)
    - [Get Video output display layout](#get-video-output-display-layout)
    - [Set Video Source in Original Layout mode](#set-video-source-in-original-layout-mode)
    - [Get Video Source in Original Layout mode](#get-video-source-in-original-layout-mode)
    - [Set Video Source in Dual Layout mode](#set-video-source-in-dual-layout-mode)
    - [Get Video Source in Dual Layout mode](#get-video-source-in-dual-layout-mode)
    - [Set Video Source in H Layout mode](#set-video-source-in-h-layout-mode)

## RS232 Default Settings

**Baud_Rate:** 115200 bps
**Data Bits:** 8 bits
**Parity:** None
**Stop bits:** 1 bit
**Flow Control:** None

## Telnet Settings

Before the process of sending the telnet command, shall make telnet connection to the corresponding device.
The form of telnet command is as follow:
`telnet ip (port)`
ip: The unit’s IP address. For example, the device’s IP address is `192.168.11.143`.
port: The unit’s port number, this is non-required on some Telnet control tools or platforms. If required, port number is `23` by default. Example: If the unit’s IP address is `192.168.11.143`,
The telnet command is telnet `192.168.11.143` Command
Take Command `SET SW in out<CR><LF>` as an example:

1. [SET SW] denotes command key words, case insensitive.
2. [in out] denotes parameters, case insensitive; incorrect
   parameters number will not be recognized.
3. `<CR><LF>` denotes a carriage return or a line feed; all
   commands must be ended up with a carriage return or a line feed.

## Commands

### Get Firmware Version

Get firmware Version

- Command: `GET VER`
- Return: `VER prm`
- Return Parameter: `firmware version`
- Example: `GET VER`
  - Returned: `VER V1.0.0`

### Set video mute status

Set video to mute

- Command: `SET VIDOUT_MUTE prm`
- Return: `VIDOUT_MUTE prm prm1`
- Parameter _prm_: 0: hdmi out, 1: in1, 2: in2, 3: in3, 4: in4
- Return Parameter: 0: Un-muted, 1: Muted
- Example: `SET VIDOUT_MUTE 1 1`
  - Returned: `VIDOUT_MUTE 1 1`

### Get Video Mute Status

Get the video mute status

- Command: `GET VIDOUT_MUTE input`
- Return: `VIDOUT_MUTE input prm`
- Parameter _input_: in1, in2, in3, in4
- Return Parmeter: 0: Un-muted, 1: Muted
- Example: `GET VIDOUT_MUTE 1`
  - Returned: `VIDOUT_MUTE 1 1`

### Set Video output resolution

Set video output resolution mode

- Command: `SET VIDOUT_RES resolution`
- Parameter _resolution_: 0: Follow Sink prefer timing, 1: Force 4K@60, 2: Force 4K@30, 3: Force 1080p@60
- Return: `VIDOUT_RES resolution`
- Example: `SET VIDOUT_RES 0`
  - Returned: `VIDOUT_RES 0`

### Get Video output resolution

Get video output resolution mode

- Command: `GET VIDOUT_RES`
- Return: `VIDOUT_RES prm`
- Returned Parameter: {0,1,2,3} 0: Follow Sink prefer timing, 1: Force 4K@60, 2: Force 4K@30, 3: Force 1080p@60
- Example: `GET VIDOUT_RES`
  - Returned: `VIDOUT_RES 0`

### Set Video output display layout

Set video output display layout

- Command: `SET VIDOUT_MODE layout`
- Return: `VIDOUT_MODE layout`
- Returned Parameter _layout_: {0,1,2,3,4} 0: Original, 1: Dual-view, 2: PiP, 3: H Mode, 4: Master, 5: Quad
- Example: `SET VIDOUT_MODE 0`
  - Returned: `VIDOUT_MODE 0`

### Get Video output display layout

Get video out put display layout

- Command: `GET VIDOUT_MODE`
- Return: `VIDOUT_MODE layout`
- Returned Parameter _layout_: {0,1,2,3,4} 0: Original, 1: Dual-view, 2: PiP, 3: H Mode, 4: Master, 5: Quad
- Example: `GET VIDOUT_MODE`
  - Returned: `VIDOUT_MODE 0`

### Set Video Source in Original Layout mode

Set the video source in original layout mode. You must be ensured in original mode this to work.

- Command: `SET VIDOUT_ORIGINAL_SRC input`
- Return: `VIDOUT_ORIGINAL_SRC input`
- Parameter _input_: {1,2,3,4} in1, in2, in3, in4
- Example: `SET VIDOUT_ORIGINAL_SRC 1`
  - Returned: `VIDOUT_ORIGINAL_SRC 1`

### Get Video Source in Original Layout mode

Get the video source in original layout mode

- Command: `GET VIDOUT_ORIGINAL_SRC`
- Return: `VIDOUT_ORIGINAL_SRC prm`
- Returned Parameter: {1,2,3,4} 1: in1, 2: in2, 3: in3, 4: in4
- Example: `GET VIDOUT_ORIGINAL_SRC`
  - Returned: `VIDOUT_ORIGINAL_SRC 0`

### Set Video Source in Dual Layout mode

Sets the video sources for the dual layout mode. Must be in Dual Layout mode to work.

- Command: `SET VIDOUT_DUAL_SRC left right`
- Return: `VIDOUT_DUAL_SRC left right`
- Parameter _left_: {1,2,3,4} Left Side in1, in2, in3, in4
- Parameter _right_: {1,2,3,4} Right Side in1, in2, in3, in4
- Example: `SET VIDOUT_DUAL_SRC 1 2`
  - Description: Screen will split in the middle. Left would show hdmi input 1, Right would show hdmi input 2.
  - Returned: `VIDOUT_DUAL_SRC 1 2`

### Get Video Source in Dual Layout mode

Gets the video sources in the Dual Layout mode

- Command: `GET VIDOUT_DUAL_SRC`
- Return: `VIDOUT_DUAL_SRC left right`
- Returned Parameter _left_: {1,2,3,4} Left Side in1, in2, in3, in4
- Returned Parameter _right_: {1,2,3,4} Right Side in1, in2, in3, in4
- Example: `GET VIDOUT_DUAL_SRC`
- Returned: `VIDOUT_DUAL_SRC 1 2`

### Set Video Source in H Layout mode

Sets the video sources in the H Layout mode. Must be in H Layout mode to work.

- Command: `SET VIDOUT_H_SRC left, top, bottom, right`
- Return: `VIDOUT_H_SRC left, top, bottom, right`
- Parameter _left_: {1,2,3,4} Left Side in1, in2, in3, in4
- Parameter _top_: {1,2,3,4} Top Side in1, in2, in3, in4
- Parameter _bottom_: {1,2,3,4} Bottom Side in1, in2, in3, in4
- Parameter _right_: {1,2,3,4} Right Side in1, in2, in3, in4
- Example: `SET VIDOUT_H_SRC 1 2 3 4`
  - Description: Split the screen into 4 images. Set input1 to the left image, input2 to the top image, input3 to the bottom image, input4 to the right image.
  - Returned: `VIDOUT_H_SRC 1 2 3 4`
